Core traits and types that abstract usage of SIMD.
Modules
- backend
- The internal low-level, primitive backend for all SIMD-focused operations.
Structs
- Lane
Count - A type that implements
SupportedLaneCountbased off the value ofN. - Simd
- A statically sized vector with
Nelements of typeT, batched into chunks of sizeLANES. - Simd
Slice - An unsized vector that implements SIMD-bound operations.
Traits
- Simd
Element - Represents a scalar that can be copied and is expected for a SIMD register.
- Simd
Scalar - A marker trait for scalars that are feasible for use in SIMD.
- Supported
Lane Count - Sealed marker trait for whether
Selfrepresents a supported lane count for a SIMD register.
Functions
- add_
arrays - Computes the value of an operation performed on arrays
aandb, returning an array of the output. - add_
arrays_ double - Computes the value of an operation performed on arrays
aandb, returning an array of the output. - add_
scalar_ array - Computes the value of an operation performed on array
abyscalar, returning an array of the output. - add_
scalar_ array_ double - Computes the value of an operation performed on array
abyscalar, returning an array of the output. - add_
scalar_ slice - Computes the value of an operation performed on a slice
abyscalar, writing the output to the specified buffer. - add_
scalar_ slice_ double - Computes the value of an operation performed on a slice
abyscalar, writing the output to the specified buffer. - add_
slices - Computes the value of an operation performed on slices
aandb, writing the output to the specified buffer. - add_
slices_ double - Computes the value of an operation performed on slices
aandb, writing the output to the specified buffer. - div_
arrays - Computes the value of an operation performed on arrays
aandb, returning an array of the output. - div_
arrays_ double - Computes the value of an operation performed on arrays
aandb, returning an array of the output. - div_
scalar_ array - Computes the value of an operation performed on array
abyscalar, returning an array of the output. - div_
scalar_ array_ double - Computes the value of an operation performed on array
abyscalar, returning an array of the output. - div_
scalar_ slice - Computes the value of an operation performed on a slice
abyscalar, writing the output to the specified buffer. - div_
scalar_ slice_ double - Computes the value of an operation performed on a slice
abyscalar, writing the output to the specified buffer. - div_
slices - Computes the value of an operation performed on slices
aandb, writing the output to the specified buffer. - div_
slices_ double - Computes the value of an operation performed on slices
aandb, writing the output to the specified buffer. - mul_
add_ scalar_ slice - A function specifically designed for SIMD-accelerated matrix multiplication.
- mul_
add_ scalar_ slice_ double - Similar to
crate::simd::mul_add_scalar_slice, only for double precision floats (f64). - mul_
arrays - Computes the value of an operation performed on arrays
aandb, returning an array of the output. - mul_
arrays_ double - Computes the value of an operation performed on arrays
aandb, returning an array of the output. - mul_
scalar_ array - Computes the value of an operation performed on array
abyscalar, returning an array of the output. - mul_
scalar_ array_ double - Computes the value of an operation performed on array
abyscalar, returning an array of the output. - mul_
scalar_ slice - Computes the value of an operation performed on a slice
abyscalar, writing the output to the specified buffer. - mul_
scalar_ slice_ double - Computes the value of an operation performed on a slice
abyscalar, writing the output to the specified buffer. - mul_
slices - Computes the value of an operation performed on slices
aandb, writing the output to the specified buffer. - mul_
slices_ double - Computes the value of an operation performed on slices
aandb, writing the output to the specified buffer. - sub_
arrays - Computes the value of an operation performed on arrays
aandb, returning an array of the output. - sub_
arrays_ double - Computes the value of an operation performed on arrays
aandb, returning an array of the output. - sub_
scalar_ array - Computes the value of an operation performed on array
abyscalar, returning an array of the output. - sub_
scalar_ array_ double - Computes the value of an operation performed on array
abyscalar, returning an array of the output. - sub_
scalar_ slice - Computes the value of an operation performed on a slice
abyscalar, writing the output to the specified buffer. - sub_
scalar_ slice_ double - Computes the value of an operation performed on a slice
abyscalar, writing the output to the specified buffer. - sub_
slices - Computes the value of an operation performed on slices
aandb, writing the output to the specified buffer. - sub_
slices_ double - Computes the value of an operation performed on slices
aandb, writing the output to the specified buffer.
Type Aliases
- Auto
Simd - A SIMD vector which has a lane count of
crate::MAX_SIMD_SINGLE_PRECISION_LANES. - Simd
Register - A SIMD vector which has a total size equal to it’s lane count.